summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexidataiteminterface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/core/kexidataiteminterface.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/core/kexidataiteminterface.h')
-rw-r--r--kexi/core/kexidataiteminterface.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/kexi/core/kexidataiteminterface.h b/kexi/core/kexidataiteminterface.h
index dbd38005..db6a9afe 100644
--- a/kexi/core/kexidataiteminterface.h
+++ b/kexi/core/kexidataiteminterface.h
@@ -20,9 +20,9 @@
#ifndef KEXIDATAITEMINTERFACE_H
#define KEXIDATAITEMINTERFACE_H
-#include <qvariant.h>
-#include <qwidget.h>
-#include <qguardedptr.h>
+#include <tqvariant.h>
+#include <tqwidget.h>
+#include <tqguardedptr.h>
class KexiDataItemInterface;
namespace KexiDB {
@@ -54,7 +54,7 @@ class KEXICORE_EXPORT KexiDataItemInterface
KexiDataItemInterface();
virtual ~KexiDataItemInterface();
/*! Just initializes \a value, and calls setValueInternal(const QString& add, bool removeOld).
If \a removeOld is true, current value is set up as \a add.
If \a removeOld if false, current value is set up as \a value + \a add.
\a value is stored as 'old value' -it'd be usable in the future
@@ -66,8 +66,8 @@ class KEXICORE_EXPORT KexiDataItemInterface
(usually a text of image) differs from the value of the widget (a numeric index).
This method is called by table view's and form's editors. */
- void setValue(const QVariant& value, const QVariant& add = QVariant(), bool removeOld = false,
- const QVariant* visibleValue = 0);
+ void setValue(const TQVariant& value, const TQVariant& add = TQVariant(), bool removeOld = false,
+ const TQVariant* visibleValue = 0);
//! \return field information for this item
virtual KexiDB::Field *field() const = 0;
@@ -84,10 +84,10 @@ class KEXICORE_EXPORT KexiDataItemInterface
// //! Sets value \a value for a widget.
// //! Just calls setValueInternal(), but also blocks valueChanged()
// //! as you we don't want to react on our own change
-// void setValue(const QVariant& value);
+// void setValue(const TQVariant& value);
//! \return value currently represented by this item.
- virtual QVariant value() = 0;
+ virtual TQVariant value() = 0;
//! \return true if editor's value is valid for a given type
//! Used for checking if an entered value is valid,
@@ -109,7 +109,7 @@ class KEXICORE_EXPORT KexiDataItemInterface
//! \return value that should be displayed for this item.
//! Only used for items like combo box, where real value is an integer while
//! displayed value is usually a text. For other item types this method should be empty.
- virtual QVariant visibleValue() { return QVariant(); }
+ virtual TQVariant visibleValue() { return TQVariant(); }
/*! \return 'readOnly' flag for this item. The flag is usually taken from
the item's widget, e.g. KLineEdit::isReadOnly().
@@ -117,7 +117,7 @@ class KEXICORE_EXPORT KexiDataItemInterface
virtual bool isReadOnly() const { return false; }
/*! \return the view widget of this item, e.g. line edit widget. */
- virtual QWidget* widget() = 0;
+ virtual TQWidget* widget() = 0;
/*! Hides item's widget, if available. */
virtual void hideWidget() { if (widget()) widget()->hide(); }
@@ -165,7 +165,7 @@ class KEXICORE_EXPORT KexiDataItemInterface
If \a readOnly is true, additional elements should be visually disabled,
e.g. dropdown button of the combobox editor should be disabled.
For reimplementation. By default does nothing. */
- virtual void showFocus( const QRect& r, bool readOnly );
+ virtual void showFocus( const TQRect& r, bool readOnly );
/*! Hides additional elements that are needed for indicating that the current cell
is selected.
@@ -188,20 +188,20 @@ class KEXICORE_EXPORT KexiDataItemInterface
bool cursorAtNewRow();
/*! Sets a pointer to a Parent Data Item Interface. This pointer is 0 by default,
- but can be set by parent widget if this interface is a building block of a larger data widget.
+ but can be set by tqparent widget if this interface is a building block of a larger data widget.
It is the case for KexiDBFieldEdit widget (see KexiDBFieldEdit::createEditor()). Use with care.
signalValueChanged() method will check this pointer, and if it's not 0,
m_parentDataItemInterface->signalValueChanged() is called, so a changes can be signalled at higher level. */
- void setParentDataItemInterface(KexiDataItemInterface* parentDataItemInterface);
+ void setParentDataItemInterface(KexiDataItemInterface* tqparentDataItemInterface);
/*! \return a pointer to a Parent Data Item Interface.
@see setParentDataItemInterface() */
- inline KexiDataItemInterface* parentInterface() const { return m_parentDataItemInterface; }
+ inline KexiDataItemInterface* tqparentInterface() const { return m_parentDataItemInterface; }
/*! Handles action having standard name \a actionName.
Action could be: "edit_cut", "edit_paste", etc.
For reimplementation. */
- virtual void handleAction(const QString& actionName) { Q_UNUSED(actionName); }
+ virtual void handleAction(const TQString& actionName) { Q_UNUSED(actionName); }
protected:
/*! Initializes this editor with \a add value, which should be somewhat added to the current
@@ -209,37 +209,37 @@ class KEXICORE_EXPORT KexiDataItemInterface
If \a removeOld is true, a value should be set to \a add, otherwise
-it should be set to current \a m_origValue + \a add, if possible.
Implement this. */
- virtual void setValueInternal(const QVariant& add, bool removeOld) = 0;
+ virtual void setValueInternal(const TQVariant& add, bool removeOld) = 0;
/*! Initializes this editor with \a value visible value.
This is currently used only in case of the combo box form widget, where displayed content
(usually a text of image) differs from the value of the widget (a numeric index).
For implementation in the combo box widget, by default does nothing. */
- virtual void setVisibleValueInternal(const QVariant& value);
+ virtual void setVisibleValueInternal(const TQVariant& value);
// //! Sets value \a value for a widget.
// //! Implement this method to allow setting value for this widget item.
-// virtual void setValueInternal(const QVariant& value) = 0;
+// virtual void setValueInternal(const TQVariant& value) = 0;
/*! Call this in your implementation when value changes,
- so installed listener can react on this change. If there is a parent data item defined
- (see setParentDataItemInterface()), parent's signalValueChanged() method will be called instead. */
+ so installed listener can react on this change. If there is a tqparent data item defined
+ (see setParentDataItemInterface()), tqparent's signalValueChanged() method will be called instead. */
virtual void signalValueChanged();
/*! Used to perform some actions before signalValueChanged() call.
- We need this because the intrface is not QObject and thus has got no real signals.
+ We need this because the intrface is not TQObject and thus has got no real signals.
Used in KexiDBComboBox. */
virtual void beforeSignalValueChanged() {};
KexiDataItemChangesListener* listener();
-//moved to KexiFormDataItemInterface: QString m_dataSource;
- QGuardedPtr<QObject> m_listenerObject;
+//moved to KexiFormDataItemInterface: TQString m_dataSource;
+ TQGuardedPtr<TQObject> m_listenerObject;
KexiDataItemChangesListener* m_listener;
- bool m_listenerIsQObject;
- QVariant m_origValue;
+ bool m_listenerIsTQObject;
+ TQVariant m_origValue;
- /*! @see parentDataItemInterface() */
+ /*! @see tqparentDataItemInterface() */
KexiDataItemInterface* m_parentDataItemInterface;
bool m_hasFocusableWidget : 1;
bool m_disable_signalValueChanged : 1;
@@ -54,7 +54,7 @@ class KEXICORE_EXPORT KexiDataItemInterface
KexiDataItemInterface();
virtual ~KexiDataItemInterface();
- /*! Just initializes \a value, and calls setValueInternal(const QString& add, bool removeOld).
+ /*! Just initializes \a value, and calls setValueInternal(const TQString& add, bool removeOld).
If \a removeOld is true, current value is set up as \a add.
If \a removeOld if false, current value is set up as \a value + \a add.